"""
Anora is a simple_tag for Django that determines whether or not a word should have an "a" or "an" in front of it. Adds either one of these depending on the phoentic value of the given text.
"""

__version__ = '0.1.0'
